Welcome to django-taggit's documentation!
=========================================

``django-taggit`` is a reusable Django application designed to make adding
tagging to your project easy and fun.

``django-taggit`` works with Django 4.1+ and Python 3.8+.

.. toctree::
   :maxdepth: 2

   getting_started
   forms
   admin
   serializers
   testing
   api
   faq
   custom_tagging
   contributing
   external_apps
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
